# AstrixRU

Библиотека для создания своих ботов в AstrixRU. Как начать?
Для начала, зарегистрируйтесь на: https://astrixru.online/register
Затем, перейдите на страницу https://astrixru.online/bots, и создайте там своего бота.
Нажмите на кнопку "Информация" (расположена на карточке вашего только что созданного бота), и найдите значение "Токен". После этого нажмите Показать, и токен скопируется сам. Документация для создания бота:
https://astrixru.online/documentation